@@ -289,8 +289,12 @@ def change_config_layer(dico_layer, wandb_config):
             dico_layer['config'][parameter] = wandb_config[layer_name + '_' + parameter]
     return dico_layer
 
-def change_config(config, wandb_config):
-    for dico_layer in config['config']['layers'][:-1]:
+def change_config(config, wandb_config, freeze_layer=None):
+    dico_layers = config['config']['layers']
+    if freeze_layer:
+        dico_layers = np.delete(dico_layers, freeze_layer)
+
+    for dico_layer in dico_layers:
         change_config_layer(dico_layer, wandb_config)
 
 def create_default(sweep_config):
